==> netxms-0.2.27.tar.gz: netxms-0.2.27/src/server/tools/nxconfig/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by nxconfig.rc
//
#define IDD_ABOUTBOX                    100
#define IDP_SOCKETS_INIT_FAILED         104
#define IDR_MAINFRAME                   128
#define IDR_NXCONFTYPE                  129
#define IDD_INTRO                       130
#define IDB_WIZARD                      131
#define IDD_SELECT_DB                   132
#define IDD_FINISH                      133
#define IDD_ODBC                        134
#define IDD_POLLING                     135
#define IDD_SMTP                        136
#define IDD_SUMMARY                     137
#define IDD_PROCESSING                  138
#define IDI_OK                          140
#define IDI_FAILED                      141
#define IDI_RUNNING                     142
#define IDD_CFG_FILE                    143
#define IDD_LOG_FILE                    144
#define IDI_WARN                        145
#define IDD_SERVICE                     146
#define IDD_SRV_DEPS                    147
#define IDC_COMBO_DBDRV                 1000
#define IDC_COMBO_DBDRV2                1001
#define IDC_COMBO_DBENGINE              1001
#define IDC_RADIO_NEWDB                 1002
#define IDC_RADIO_EXISTINGDB            1003
#define IDC_EDIT_SERVER                 1004
#define IDC_EDIT_DBA_LOGIN              1005
#define IDC_EDIT_DBA_PASSWORD           1006
#define IDC_EDIT_DB_NAME                1007
#define IDC_EDIT_DB_LOGIN               1008
#define IDC_EDIT_DB_PASSWORD            1009
#define IDC_CHECK_INITDB                1010
#define IDC_BUTTON_ODBC                 1011
#define IDC_CHECK_RUN_DISCOVERY         1012
#define IDC_STATIC_DI                   1013
#define IDC_EDIT_INT_DP                 1014
#define IDC_STATIC_SEC                  1015
#define IDC_EDIT_NUM_SP                 1016
#define IDC_EDIT_INT_SP                 1018
#define IDC_EDIT_EMAIL                  1018
#define IDC_EDIT_SUMMARY                1019
#define IDC_EDIT_NUM_CP                 1020
#define IDC_STATIC_STATUS               1020
#define IDC_EDIT_INT_CP                 1021
#define IDC_LIST_STATUS                 1021
#define IDC_EDIT_FILE                   1022
#define IDC_BUTTON_BROWSE               1023
#define IDC_RADIO_SYSLOG                1024
#define IDC_RADIO_FILE                  1025
#define IDC_STATIC_SERVER               1028
#define IDC_COMBO_SMSDRV                1029
#define IDC_COMBO_PORT                  1030
#define IDC_STATIC_PORT                 1031
#define IDC_STATIC_DBNAME               1032
#define IDC_RADIO_SYSTEM                1033
#define IDC_RADIO_USER                  1034
#define IDC_EDIT_LOGIN                  1035
#define IDC_EDIT_PASSWD1                1036
#define IDC_EDIT_PASSWD2                1037
#define IDC_ICON_WARNING                1038
#define IDC_STATIC_WARNING              1039
#define IDC_LIST_SERVICES               1040
#define ID_FILE_CFG_WIZARD              32771

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        148
#define _APS_NEXT_COMMAND_VALUE         32772
#define _APS_NEXT_CONTROL_VALUE         1041
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> netxms-2.2.11.tar.gz: netxms-2.2.11/src/server/tools/nxconfig/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by nxconfig.rc
//
#define IDD_ABOUTBOX                    100
#define IDP_SOCKETS_INIT_FAILED         104
#define IDR_MAINFRAME                   128
#define IDR_NXCONFTYPE                  129
#define IDD_INTRO                       130
#define IDB_WIZARD                      131
#define IDD_SELECT_DB                   132
#define IDD_FINISH                      133
#define IDD_ODBC                        134
#define IDD_POLLING                     135
#define IDD_SMTP                        136
#define IDD_SUMMARY                     137
#define IDD_PROCESSING                  138
#define IDI_OK                          140
#define IDI_FAILED                      141
#define IDI_RUNNING                     142
#define IDD_CFG_FILE                    143
#define IDD_LOG_FILE                    144
#define IDI_WARN                        145
#define IDD_SERVICE                     146
#define IDD_SRV_DEPS                    147
#define IDC_COMBO_DBDRV                 1000
#define IDC_COMBO_DBDRV2                1001
#define IDC_COMBO_DBENGINE              1001
#define IDC_RADIO_NEWDB                 1002
#define IDC_RADIO_EXISTINGDB            1003
#define IDC_EDIT_SERVER                 1004
#define IDC_EDIT_DBA_LOGIN              1005
#define IDC_EDIT_DBA_PASSWORD           1006
#define IDC_EDIT_DB_NAME                1007
#define IDC_EDIT_DB_LOGIN               1008
#define IDC_EDIT_DB_PASSWORD            1009
#define IDC_CHECK_INITDB                1010
#define IDC_BUTTON_ODBC                 1011
#define IDC_CHECK_RUN_DISCOVERY         1012
#define IDC_STATIC_DI                   1013
#define IDC_EDIT_INT_DP                 1014
#define IDC_STATIC_SEC                  1015
#define IDC_EDIT_NUM_SP                 1016
#define IDC_EDIT_INT_SP                 1018
#define IDC_EDIT_EMAIL                  1018
#define IDC_EDIT_SUMMARY                1019
#define IDC_EDIT_NUM_CP                 1020
#define IDC_STATIC_STATUS               1020
#define IDC_EDIT_POLLER_TP_MAX          1020
#define IDC_LIST_STATUS                 1021
#define IDC_EDIT_FILE                   1022
#define IDC_BUTTON_BROWSE               1023
#define IDC_EDIT_NUM_CP2                1023
#define IDC_EDIT_POLLER_TP_BASE         1023
#define IDC_RADIO_SYSLOG                1024
#define IDC_RADIO_FILE                  1025
#define IDC_STATIC_SERVER               1028
#define IDC_COMBO_SMSDRV                1029
#define IDC_COMBO_PORT                  1030
#define IDC_STATIC_PORT                 1031
#define IDC_STATIC_DBNAME               1032
#define IDC_RADIO_SYSTEM                1033
#define IDC_RADIO_USER                  1034
#define IDC_EDIT_LOGIN                  1035
#define IDC_EDIT_PASSWD1                1036
#define IDC_EDIT_PASSWD2                1037
#define IDC_ICON_WARNING                1038
#define IDC_STATIC_WARNING              1039
#define IDC_LIST_SERVICES               1040
#define IDC_CHECK_MANUAL_START          1042
#define IDC_EDIT_INT_CP                 1043
#define IDC_EDIT_INT_TP                 1044
#define ID_FILE_CFG_WIZARD              32771

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        160
#define _APS_NEXT_COMMAND_VALUE         32772
#define _APS_NEXT_CONTROL_VALUE         1045
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
